@@ -27,14 +27,14 @@ def ll_read(address):
 	global DEBUG_OUTPUT
 	poll=0
 	while int(os.popen('cat /proc/InnoRoute/SPI_write').read())>0:
-		time.sleep(0.1)
+		time.sleep(0.01)
 		poll=poll+1
 		if poll>pollcount:
 			return 0
 	os.popen('echo '+str(address)+' > /proc/InnoRoute/SPI_read')
 	if DEBUG_OUTPUT:
 		print("TNbar1 "+hex(address))
-#	time.sleep(0.1)
+	time.sleep(0.01)
 	return int(os.popen('cat /proc/InnoRoute/SPI_data').read(),16)
 	
 def __debug(message):
@@ -55,7 +55,7 @@ def ll_write(address,value):
 			return 0
 	os.popen('echo '+str(value)+' > /proc/InnoRoute/SPI_data')
 	os.popen('echo '+str(address)+' > /proc/InnoRoute/SPI_write')
-	time.sleep(0.1)
+	time.sleep(0.01)
 	__debug(hex(value)+" written to "+hex(address))
 	if DEBUG_OUTPUT:
 		print("TNbar1 "+hex(address)+" "+hex(value))
@@ -89,6 +89,7 @@ def get_addr(register):
 def status():
 	FPGA_status={}
 	FPGA_status["ID"]=hex(reg_read("C_ADDR_SPI_FPGA_ID0")+(reg_read("C_ADDR_SPI_FPGA_ID1") << 32))
+	FPGA_status["ACCESS_ERROR"]=hex(reg_read("C_ADDR_SPI_ACCESS_ERROR"))
 	FPGA_status["Board_REV"]=hex(reg_read("C_ADDR_SPI_BOARD_REV"))
 	FPGA_status["TEMP"]=reg_read("C_ADDR_SPI_FPGA_TEMP")*504/4096-273
 	FPGA_status["FPGA_REV"]=hex(reg_read("C_ADDR_SPI_FPGA_REV"))	
@@ -100,7 +101,6 @@ def status():
 	FPGA_status["FPGA_ALARM"]=hex(reg_read("C_ADDR_SPI_FPGA_ALARM"))
 	FPGA_status["CONFIG_CHECK"]=hex(reg_read("C_ADDR_SPI_CONFIG_CHECK"))
 	FPGA_status["LICENSE"]=hex(reg_read("C_ADDR_SPI_LICENSE"))
-	FPGA_status["ACCESS_ERROR"]=hex(reg_read("C_ADDR_SPI_ACCESS_ERROR"))
 	FPGA_status["FIFO_OVERFLOW"]=hex(reg_read("C_ADDR_SPI_FIFO_OVERFLOW"))
 	FPGA_status["FIFO_UNDERRUN"]=hex(reg_read("C_ADDR_SPI_FIFO_UNDERRUN"))
 	FPGA_status["EXT_INTERRUPT"]=hex(reg_read("C_ADDR_SPI_EXT_INTERRUPT"))
@@ -113,8 +113,8 @@ def status():
 	return FPGA_status
 	
 def license_features():
-	FPGA_features=[]
-	featuremap=0
+	FPGA_features=[]	
+	featuremap=reg_read("C_ADDR_SPI_LICENSE")>>8
 	for x in range(32):
 		if check_register("FEATURE_"+str(x)+'_NAME'):
 			FPGA_features.append({"name":environment["FEATURE_"+str(x)+'_NAME'],"description":environment["FEATURE_"+str(x)+'_DESCRIPTION'],"status":(featuremap & (1<< x)) > 0})
