@@ -12,7 +12,7 @@ DEBUG_ENABLE=False
 DEBUG_OUTPUT=False
 __correct_value_up=True
 AUTOCORRECT_GCL=True
-__pollcount=100
+__pollcount=1000
 __timewindow=2000000000
 
 def __init_TASvar():
@@ -145,10 +145,14 @@ def set_GCL(new_GCL,port):
 			raise Exception("entry "+str(entry)+" of gcl is not valid")
 	if AUTOCORRECT_GCL:
 		new_GCL=__blowup_GCL(new_GCL)	
+	__GCL[port]=[]
 	for entry in new_GCL:	
 		if (int(entry[1]) % int(__TASvar["granularity"]))>0:
 			print("Warning: entry "+str(entry)+" of GCL don't match minimal TAS ganularity of "+str(__TASvar["granularity"])+"ns")
-	__GCL[port]=new_GCL
+		__correct_value_up=False		
+		__GCL[port].append([entry[0],__correct_value(entry[1])])
+	
+	
 	
 	
 def get_GCL(port):
@@ -156,6 +160,9 @@ def get_GCL(port):
 	__checkport(port)
 	return __GCL[port]
 
+def get_portalign_base_addr(addr,port):
+	return __portalign_base_addr(addr,port)
+	
 def __portalign_base_addr(addr,port):
 	__checkport(port)
 	return RT_HAT_FPGA.get_addr(addr)+port*get_TASvar("PORT_TSN_width")
@@ -175,6 +182,9 @@ def __apply_GCL(port):
 		ID=ID+1
 	RT_HAT_FPGA.ll_write(__portalign_base_addr("C_ADDR_TM_SCHED_TAS_ADMIN_GCL_LEN",port),len(__GCL[port]))
 	
+def set_trigger_en(val):
+	RT_HAT_FPGA.ll_write(__portalign_base_addr("C_ADDR_TM_SCHED_TAS_TRIGGER_EN",2),val)
+	
 
 	
 @with_goto		
